OC.L10N.register(
    "core",
    {
    "Please select a file." : "Изаберите фајл.",
    "File is too big" : "Фајл је превелик",
    "The selected file is not an image." : "Изабрани фајл није слика.",
    "The selected file cannot be read." : "Није могуће читати изабрани фајл.",
    "The file was uploaded" : "Фајл је отпремљен",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Фајл за отпремање премашује upload_max_filesize директиву у php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Отпремани фајл превазилази смерницу MAX_FILE_SIZE наведену у HTML обрасцу",
    "The file was only partially uploaded" : "Фајл је парцијално отпремљен",
    "No file was uploaded" : "Није отпремљен фајл",
    "Missing a temporary folder" : "Недостаје привремена фасцикла",
    "Could not write file to disk" : "Не могу да упишем фајл на диск",
    "A PHP extension stopped the file upload" : "ПХП екстензија је зауставила отпремање фајла",
    "Invalid file provided" : "Понуђени фајл није исправан",
    "No image or file provided" : "Нису понуђени ни слика ни фајл",
    "Unknown filetype" : "Непознат тип фајла",
    "An error occurred. Please contact your admin." : "Дошло је до грешке. Контактирајте администратора.",
    "Invalid image" : "Неисправна слика",
    "No temporary profile picture available, try again" : "Нема привремене слике профила. Покушајте поново",
    "No crop data provided" : "Нема података о опсецању",
    "No valid crop data provided" : "Нема исправних података о опсецању",
    "Crop is not square" : "Опсецање није квадратног облика",
    "State token does not match" : "Стање жетона се не слаже",
    "Invalid app password" : "Неисправна апликативна лозинка",
    "Could not complete login" : "Не могу да довршим пријављивање",
    "State token missing" : "Недостаје жетон стања",
    "Your login token is invalid or has expired" : "Ваш жетон за пријављивање је неисправан или је истекао",
    "Please use original client" : "Молимо вас да користите оригинални клијент",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Ово Nextcloud издање заједнице није подржано и брза обавештења су ограничена.",
    "Login" : "Пријава",
    "Unsupported email length (>255)" : "Није подржана дужина и-мејла (>255)",
    "Password reset is disabled" : "Ресетовање лозинке није омогућено",
    "Could not reset password because the token is expired" : "Лозинка није могла да се ресетује јер је истекао жетон",
    "Could not reset password because the token is invalid" : "Лозинка није могла да се ресетује јер жетон не важи",
    "Password is too long. Maximum allowed length is 469 characters." : "Лозинка је сувише дугачка. Дозвољено је највише 469 знакова.",
    "%s password reset" : "%s лозинка ресетована",
    "Password reset" : "Ресетовање лозинке",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Кликните следеће дугме за ресетовање лозинке. Ако нисте тражили ресетовање лозинке, занемарите ову поруку.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Кликните следећу везу за ресетовање лозинке. Ако нисте тражили ресетовање лозинке, занемарите ову поруку.",
    "Reset your password" : "Ресетуј лозинку",
    "The given provider is not available" : "Наведен пружалац услуге није доступан",
    "Task not found" : "Задатак није пронађен",
    "Internal error" : "Интерна грешка",
    "Not found" : "Није нађено",
    "Node is locked" : "Чвор је закључан.",
    "Bad request" : "Неисправан захтев",
    "Requested task type does not exist" : "Тражени тип задатка не постоји",
    "Necessary language model provider is not available" : "Није доступан неопходни пружалац услуге језичког модела",
    "No text to image provider is available" : "Није доступан ниједан пружалац услуге генерисања слике из текста",
    "Image not found" : "Слика није пронађена",
    "No translation provider available" : "Није доступан ниједан пружалац услуге превода",
    "Could not detect language" : "Не може да се детектује језик",
    "Unable to translate" : "Не може да се преведе",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Корак поправке:",
    "Repair info:" : "Инфо о поправци:",
    "Repair warning:" : "Упозорење о поправци:",
    "Repair error:" : "Грешка поправке:",
    "Nextcloud Server" : "Nextcloud сервер",
    "Some of your link shares have been removed" : "Неке везе дељења су уклоњене",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Услед безбедоносних мера, морали смо да уклонимо неке од ваших веза дељења. Кликните везу за више информација.",
    "The account limit of this instance is reached." : "Достигнута је граница броја налога на овој инстанци.",
    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Унестите ваш кључ претплате у апликацију за подршку да бисте увећали границу броја налога. На овај начин добијате још погодности које нуди Nextcloud Enterprise и топло се препоручује за рад у компанијама.",
    "Learn more ↗" : "Сазнајте више ↗",
    "Preparing update" : "Припремам ажурирање",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Молимо вас да користите алат за ажурирање из командне линије јер је ажурирање из прегледача искључено у вашем config.php.",
    "Turned on maintenance mode" : "Режим одржавања укључен",
    "Turned off maintenance mode" : "Режим одржавања искључен",
    "Maintenance mode is kept active" : "Режим одржавања се држи активним",
    "Updating database schema" : "Освежава се шема базе података",
    "Updated database" : "База података ажурирана",
    "Update app \"%s\" from App Store" : "Ажурирај апликацију „%s” из Продавнице апликација",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Провера да ли шема базе података за %s може бити ажурирана (ово може да потраје, у зависности од величине базе)",
    "Updated \"%1$s\" to %2$s" : "„%1$s“ ажурирано на %2$s",
    "Set log level to debug" : "Постави ниво дневника на дебаговање",
    "Reset log level" : "Ресетуј ниво уписа у дневник",
    "Starting code integrity check" : "Почињем проверу интегритета кода",
    "Finished code integrity check" : "Завршена провера интегритета кода",
    "%s (incompatible)" : "%s (некомпатибилан)",
    "The following apps have been disabled: %s" : "Следеће апликације су искључене: %s",
    "Already up to date" : "Већ је ажурна",
    "Windows Command Script" : "Windows командна скрипта",
    "Electronic book document" : "Документ електронске књиге",
    "TrueType Font Collection" : "Колекција TrueType фонтова",
    "Web Open Font Format" : "Web Open Font формат",
    "GPX geographic data" : "GPX географски подаци",
    "Gzip archive" : "Gzip архива",
    "Adobe Illustrator document" : "Adobe Illustrator документ",
    "Java source code" : "Java изворни кôд",
    "JavaScript source code" : "JavaScript изворни кôд",
    "JSON document" : "JSON документ",
    "Microsoft Access database" : "Microsoft Access база података",
    "Microsoft OneNote document" : "Microsoft OneNote документ",
    "Microsoft Word document" : "Microsoft Word документ",
    "Unknown" : "Непознато",
    "PDF document" : "PDF документ",
    "PostScript document" : "PostScript документ",
    "RSS summary" : "RSS сажетак",
    "Android package" : "Android пакет",
    "KML geographic data" : "KML географски подаци",
    "KML geographic compressed data" : "KML компресовани географски подаци",
    "Lotus Word Pro document" : "Lotus Word Pro документ",
    "Excel spreadsheet" : "Excel табела",
    "Excel add-in" : "Excel додатак",
    "Excel 2007 binary spreadsheet" : "Excel 2007 бинарна табела",
    "Excel spreadsheet template" : "Excel шаблон табеле",
    "Outlook Message" : "Outlook порука",
    "PowerPoint presentation" : "PowerPoint презентација",
    "PowerPoint add-in" : "PowerPoint додатак",
    "PowerPoint presentation template" : "PowerPoint шаблон презентације",
    "Word document" : "Word документ",
    "ODF formula" : "ODF формула",
    "ODG drawing" : "ODG цртеж",
    "ODG drawing (Flat XML)" : "ODG цртеж (Равни XML)",
    "ODG template" : "ODG шаблон",
    "ODP presentation" : "ODP презентација",
    "ODP presentation (Flat XML)" : "ODP презентација (РавниXML)",
    "ODP template" : "ODP шаблон",
    "ODS spreadsheet" : "ODS табела",
    "ODS spreadsheet (Flat XML)" : "ODS табела (Равни XML)",
    "ODS template" : "ODS шаблон",
    "ODT document" : "ODT документ",
    "ODT document (Flat XML)" : "ODT документ (Равни XML)",
    "ODT template" : "ODT шаблон",
    "PowerPoint 2007 presentation" : "PowerPoint 2007 презентација",
    "PowerPoint 2007 show" : "PowerPoint 2007 шоу",
    "PowerPoint 2007 presentation template" : "PowerPoint 2007 шаблон презентације",
    "Excel 2007 spreadsheet" : "Excel 2007 табела",
    "Excel 2007 spreadsheet template" : "Excel 2007 шаблон табеле",
    "Word 2007 document" : "Word 2007 документ",
    "Word 2007 document template" : "Word 2007 шаблон документа",
    "Microsoft Visio document" : "Microsoft Visio документ",
    "WordPerfect document" : "WordPerfect документ",
    "7-zip archive" : "7-zip архива",
    "Blender scene" : "Blender сцена",
    "Bzip2 archive" : "Bzip2 архива",
    "Debian package" : "Debian пакет",
    "FictionBook document" : "FictionBook документ",
    "Unknown font" : "Непознати фонт",
    "Krita document" : "Krita документ",
    "Mobipocket e-book" : "Mobipocket е-књига",
    "Windows Installer package" : "Windows Installer пакет",
    "Perl script" : "Perl скрипта",
    "PHP script" : "PHP скрипта",
    "Tar archive" : "Tar архива",
    "XML document" : "XML документ",
    "YAML document" : "YAML документ",
    "Zip archive" : "Zip архива",
    "Zstandard archive" : "Zstandard архива",
    "AAC audio" : "AAC аудио",
    "FLAC audio" : "FLAC аудио",
    "MPEG-4 audio" : "MPEG-4 аудио",
    "MP3 audio" : "MP3 аудио",
    "Ogg audio" : "Ogg аудио",
    "RIFF/WAVe standard Audio" : "RIFF/WAVe стандардни аудио",
    "WebM audio" : "WebM аудио",
    "MP3 ShoutCast playlist" : "MP3 ShoutCast плејлиста",
    "Windows BMP image" : "Windows BMP слика",
    "Better Portable Graphics image" : "Better Portable Graphics слика",
    "EMF image" : "EMF слика",
    "GIF image" : "GIF слика",
    "HEIC image" : "HEIC слика",
    "HEIF image" : "HEIF слика",
    "JPEG-2000 JP2 image" : "JPEG-2000 JP2 слика",
    "JPEG image" : "JPEG слика",
    "PNG image" : "ПНГ слика",
    "SVG image" : "SVG слика",
    "Truevision Targa image" : "Truevision Targa слика",
    "TIFF image" : "TIFF слика",
    "WebP image" : "WebP слика",
    "Digital raw image" : "Сирова дигитална слика",
    "Windows Icon" : "Windows икона",
    "Email message" : "И-мејл порука",
    "VCS/ICS calendar" : "VCS/ICS календар",
    "CSS stylesheet" : "CSS листа стилова",
    "CSV document" : "CSV документ",
    "HTML document" : "HTML документ",
    "Markdown document" : "Markdown документ",
    "Org-mode file" : "Фајл org-режима",
    "Plain text document" : "Документ чистог текста",
    "Rich Text document" : "Документ обогаћеног текста",
    "Electronic business card" : "Електронска визит карта",
    "C++ source code" : "C++ изворни кôд",
    "LDIF address book" : "LDIF адресар",
    "NFO document" : "NFO документ",
    "PHP source" : "PHP извор",
    "Python script" : "Python скрипта",
    "ReStructuredText document" : "ReStructuredText документ",
    "3GPP multimedia file" : "3GPP мултимедијални фајл",
    "MPEG video" : "MPEG видео",
    "DV video" : "DV видео",
    "MPEG-2 transport stream" : "MPEG-2 транспортни ток",
    "MPEG-4 video" : "MPEG-4 видео",
    "Ogg video" : "Ogg видео",
    "QuickTime video" : "QuickTime видео",
    "WebM video" : "WebM видео",
    "Flash video" : "Flash видео",
    "Matroska video" : "Matroska видео",
    "Windows Media video" : "Windows Media видео",
    "AVI video" : "AVI видео",
    "unknown text" : "непознат текст",
    "Hello world!" : "Здраво свете!",
    "sunny" : "сунчано",
    "Hello {name}, the weather is {weather}" : "Здраво {name}, време је {weather}",
    "Hello {name}" : "Здраво {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Ово су резултати Ваше претраге<script>alert(1)</script></strong>",
    "new" : "ново",
    "_download %n file_::_download %n files_" : ["преузми %n фајл","преузми %n фајла","преузми %n фајлова"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Ажурирање је у току. У неким окружењима, напуштање ове стране може да прекине овај процес.",
    "Update to {version}" : "Ажурирај на {version}",
    "An error occurred." : "Дошло је до грешке.",
    "Please reload the page." : "Поново учитајте страницу.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Ажурирање није успело. За више информација <a href=\"{url}\">погледајте нашу објаву на форуму</a> која обрађује ову тему.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Ажурирање није успело. Пријавите овај проблем <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Некстклауд заједници</a>.",
    "Continue to {productName}" : "Наставите на {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Ажурирање је било успешно. Преусмеравате се на {productName} за %n секунду.","Ажурирање је било успешно. Преусмеравате се на {productName} за %n секунде.","Ажурирање је било успешно. Преусмеравате се на {productName} за  %n секунди."],
    "Applications menu" : "Мени апликација",
    "Apps" : "Апликације",
    "More apps" : "Још апликација",
    "_{count} notification_::_{count} notifications_" : ["{count} обавештење","{count} обавештења","{count} обавештења"],
    "No" : "Не",
    "Yes" : "Да",
    "The remote URL must include the user." : "Удаљени URL мора да садржи кориника.",
    "Invalid remote URL." : "Неисправан удаљени URL.",
    "Failed to add the public link to your Nextcloud" : "Неуспело додавање јавне везе ка Вашем Некстклауду",
    "Federated user" : "Федерисани корисник",
    "user@your-nextcloud.org" : "korisnik@vas-nextcloud.org",
    "Create share" : "Kreirajte deljenje",
    "Direct link copied" : "Директни линк је копиран",
    "Please copy the link manually:" : "Молимо вас да ручно корпирате линк:",
    "Custom date range" : "Произвољни опсег датума",
    "Pick start date" : "Изаберите почетни датум",
    "Pick end date" : "Изаберите крајњи датум",
    "Search in date range" : "Претражи у опсегу датума",
    "Search in current app" : "Претражи у тренутној апликацији",
    "Clear search" : "Обриши претрагу",
    "Search everywhere" : "Претражи свуда",
    "Searching …" : "Тражим…",
    "Start typing to search" : "Почните да куцате да бисте претраживали",
    "No matching results" : "Претрага није дала резултате",
    "Today" : "Данас",
    "Last 7 days" : "Последњих 7 дана",
    "Last 30 days" : "Последњих 30 дана",
    "This year" : "Ове године",
    "Last year" : "Прошле године",
    "Unified search" : "Обједињена претрага",
    "Search apps, files, tags, messages" : "Претражи апликације, фајлове, ознаке, поруке",
    "Places" : "Места",
    "Date" : "Датум",
    "Search people" : "Претрага људи",
    "People" : "Људи",
    "Filter in current view" : "Филтрирај у текућем погледу",
    "Search connected services" : "Претражи повезане уређаје",
    "Results" : "Резултати",
    "Load more results" : "Учитај још резултата",
    "Search in" : "Претражи у",
    "Log in" : "Пријава",
    "Logging in …" : "Пријављивање …",
    "Log in to {productName}" : "Пријавите се на {productName}",
    "Wrong login or password." : "Погрешно име за пријаву или лозинка",
    "This account is disabled" : "Овај налог је искључен",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Приметили смо више неисправних покушаја пријава са Ваше IP адресе. Следећа пријава ће бити могућа тек за 30 секунди.",
    "Account name or email" : "Име налога или е-адреса",
    "Account name" : "Име рачуна",
    "Server side authentication failed!" : "Потврда идентитета на серверу није успела!",
    "Please contact your administrator." : "Контактирајте вашег администратора.",
    "Session error" : "Грешка сесије",
    "It appears your session token has expired, please refresh the page and try again." : "Изгледа да је истекао ваш жетон сесије, молимо вас да освежите страницу и покушате поново.",
    "An internal error occurred." : "Догодила се унутрашња грешка. ",
    "Please try again or contact your administrator." : "Покушајте поново или контактирајте вашег администратора.",
    "Password" : "Лозинка",
    "Log in with a device" : "Пријава са уређајем",
    "Login or email" : "Име за пријаву или и-мејл",
    "Your account is not setup for passwordless login." : "Ваш налог није подешен за пријаву без лозинке.",
    "Your connection is not secure" : "Ваша веза није безбедна",
    "Passwordless authentication is only available over a secure connection." : "Пријављивање без лозинке је доступно само на безбедним конекцијама.",
    "Browser not supported" : "Веб читач није подржан",
    "Passwordless authentication is not supported in your browser." : "Ваш веб читач не подржава пријављивање без лозинке.",
    "Reset password" : "Ресетуј лозинку",
    "Back to login" : "Назад на пријаву",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Ако овај налог постоји, на његову и-мејл адресу је послата порука за ресетовање лозинке. Ако је не примите, потврдите своју и-мејл адресу и/или име за пријаву, проверите фолдере за нежељену пошту, или потражите помоћ свог локалног администратора.",
    "Couldn't send reset email. Please contact your administrator." : "Не могу да пошаљем поруку за ресетовање. Контактирајте администратора.",
    "Password cannot be changed. Please contact your administrator." : "Лозинка не може да се промени. Молимо вас контактирајте администратора.",
    "New password" : "Нова лозинка",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Ваши фајлови су шифровани. Не постоји ниједан начин да се Ваши подаци поврате ако се лозинка сад ресетује. Уколико нисте сигурни шта да радите, контактирајте Вашег администратора пре него што наставите. Да ли стварно желите да наставите?",
    "I know what I'm doing" : "Знам шта радим",
    "Resetting password" : "Ресетујем лозинку",
    "Schedule work & meetings, synced with all your devices." : "Закажите посао & састанке, синхронизовано на све ваше уређаје.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Држите колеге и пријатеље на једном месту без цурења приватних података.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Једноставна е-мејл апликација која се лепо интегрише са Фајловима, Контактима и Календаром.",
    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Ћаскање, видео позиви, дељење екрана, састанци на интернету и веб конференције – у интернет прегледачу и са мобилним апликацијама.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Заједнички документи, табеле и презентације, изграђени на Collabora Online.",
    "Distraction free note taking app." : "Апликација за вођење бележака без ометања.",
    "Recommended apps" : "Препоручене апликације",
    "Loading apps …" : "Учитавам апликације…",
    "Could not fetch list of apps from the App Store." : "Листа апликација није могла да се преузме са продавнице апликација.",
    "App download or installation failed" : "Скидање или инсталирање апликације није успело",
    "Cannot install this app because it is not compatible" : "Ова апликација не може да се инсталира јер није компатибилна",
    "Cannot install this app" : "Ова апликација не може да се инсталира",
    "Skip" : "Preskoči",
    "Installing apps …" : "Инсталирам апликације…",
    "Install recommended apps" : "Инсталирајте препоручене апликације",
    "Avatar of {displayName}" : "Аватар корисника {displayName}",
    "Settings menu" : "Мени подешавања",
    "Loading your contacts …" : "Учитавам контакте ...",
    "Looking for {term} …" : "Тражим {term} …",
    "Search contacts" : "Претрага контакта",
    "Reset search" : "Ресетуј претрагу",
    "Search contacts …" : "Претражи контакте ...",
    "Could not load your contacts" : "Не могу да учитам Ваше контакте",
    "No contacts found" : "Контакти нису нађени",
    "Show all contacts" : "Прикажи све контакте",
    "Install the Contacts app" : "Инсталирај апликацију Контакти",
    "Search" : "Претражи",
    "No results for {query}" : "Нема резултата за упит {query}",
    "Press Enter to start searching" : "Притисните Ентер да започнете претрагу",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Унесите {minSearchLength} или више карактера да бисте претраживали","Унесите {minSearchLength} или више карактера да бисте претраживали","Унесите {minSearchLength} или више карактера да бисте претраживали"],
    "An error occurred while searching for {type}" : "Десила се грешка приликом тражења за {type}",
    "Search starts once you start typing and results may be reached with the arrow keys" : "Претрага започиње чим почнете да куцате и до резултата долазите курсорским тастерима",
    "Search for {name} only" : "Тражи само за {name}",
    "Loading more results …" : "Учитавам још резултата…",
    "Forgot password?" : "Заборавили сте лозинку?",
    "Back to login form" : "Назад на формулар за пријаву",
    "Back" : "Назад",
    "Login form is disabled." : "Форма за пријаву је искључена.",
    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud формулар за пријаву је искључен. Ако је доступна, користите неку другу могућност пријаве, или се обратите администрацији.",
    "More actions" : "Још акција",
    "User menu" : "Кориснички мени",
    "Your guest name: {user}" : "Ваше име госта: {user}",
    "You are currently not identified." : "Тренутно нисте идентификовани.",
    "Set public name" : "Постави јавно име",
    "Change public name" : "Измени јавно име",
    "Password is too weak" : "Лозинка је сувише слаба",
    "Password is weak" : "Лозинка је слаба",
    "Password is average" : "Лозинка је просечна",
    "Password is strong" : "Лозинка је јака",
    "Password is very strong" : "Лозинка је веома јака",
    "Password is extremely strong" : "Лозинка је екстремно јака",
    "Unknown password strength" : "Лозинка је непознате јачине",
    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Ваш директоријум са подацима и фајлови су вероватно доступни са интернета јер <code>.htaccess</code> фајл не ради.",
    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "За информације у вези са правилним подешавањем вашег сервера, молимо вас да {linkStart}погледајте документацију{linkEnd}",
    "Autoconfig file detected" : "Откривен је фајл аутоматског подешавања",
    "The setup form below is pre-filled with the values from the config file." : "Формулар подешавања испод је унапред попуњен са вредностима из конфигурационог фајла.",
    "Security warning" : "Безбедносно упозорење",
    "Create administration account" : "Направи административни налог",
    "Administration account name" : "Име административног налога",
    "Administration account password" : "Лозинка административног налога",
    "Storage & database" : "Складиште и база података",
    "Data folder" : "Фасцикла за податке",
    "Database configuration" : "Конфигурација базе података",
    "Only {firstAndOnlyDatabase} is available." : "Доступна је само {firstAndOnlyDatabase}.",
    "Install and activate additional PHP modules to choose other database types." : "Инсталирајте и активирајте додатне „ПХП“ модуле за одабир других база података.",
    "For more details check out the documentation." : "За више детаља погледајте документацију.",
    "Performance warning" : "Упозорење о перформансама",
    "You chose SQLite as database." : "Одабрали сте SQLite за базу података.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite треба да се користи само за најмање инстанце или за инстанце за развој. За продукцију, препоручујемо други тип база података.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Коришћење SQLite базе података нарочите није препоручљиво ако користите клијенте за синхронизацију фајлова.",
    "Database user" : "Корисник базе",
    "Database password" : "Лозинка базе",
    "Database name" : "Назив базе",
    "Database tablespace" : "Радни простор базе података",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Наведите и број порта у имену домаћина (нпр. localhost:5432).",
    "Database host" : "Домаћин базе",
    "localhost" : "локални хост",
    "Installing …" : "Инсталирам ...",
    "Install" : "Инсталирај",
    "Need help?" : "Треба вам помоћ?",
    "See the documentation" : "Погледајте документацију",
    "{name} version {version} and above" : "{name} верзија {version} и новије",
    "This browser is not supported" : "Овај веб читач није подржан",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Ваш веб читач није подржан. Молимо вас да га ажурирате на новију верзију, или да инсталирате подржани читач.",
    "Continue with this unsupported browser" : "Настави са овим неподржаним читачем",
    "Supported versions" : "Подржане верзије",
    "Search {types} …" : "Претражи {types}…",
    "Choose {file}" : "Изабери {file}",
    "Choose" : "Изаберите",
    "Copy to {target}" : "Копирај у {target}",
    "Copy" : "Копирај",
    "Move to {target}" : "Премести у {target}",
    "Move" : "Премести",
    "OK" : "У реду",
    "read-only" : "само-за-читање",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} сукоб фајлова","{count} сукоба фајлова","{count} сукоба фајлова"],
    "One file conflict" : "Један сукоб фајлова",
    "New Files" : "Нови фајлови",
    "Already existing files" : "Постојећи фајлови",
    "Which files do you want to keep?" : "Које фајлове желите да задржите?",
    "If you select both versions, the copied file will have a number added to its name." : "Ако изаберете обе верзије, копираном фајлу ће бити додат број у називу.",
    "Cancel" : "Одустани",
    "Continue" : "Настави",
    "(all selected)" : "(све изабрано)",
    "({count} selected)" : "(изабрано: {count})",
    "Error loading file exists template" : "Грешка при учитавању шаблона „Фајл постоји“",
    "Saving …" : "Чувам…",
    "seconds ago" : "пре пар секунди",
    "Connection to server lost" : "Изгубљена је веза са сервером",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Грешка приликом учитавања стране, пробам поново за %n секунду","Грешка приликом учитавања стране, пробам поново за %n секунде","Грешка приликом учитавања стране, пробам поново за %n секунди"],
    "Add to a project" : "Додај у пројекат",
    "Show details" : "Прикажи детаље",
    "Hide details" : "Сакриј детаље",
    "Rename project" : "Преименуј пројекат",
    "Failed to rename the project" : "Грешка при преименовању пројекат",
    "Failed to create a project" : "Грешка при креирању пројекта",
    "Failed to add the item to the project" : "Грешка приликом додавања ставке у пројекат",
    "Connect items to a project to make them easier to find" : "Повежите ставке у пројекат да Вам буде лакше да их нађете",
    "Type to search for existing projects" : "Крените да куцате да тражите постојеће пројекте",
    "New in" : "Ново у",
    "View changelog" : "Погледајте дневник измена",
    "No action available" : "Нема доступне радње",
    "Error fetching contact actions" : "Грешка приликом дохватања акција над контактима",
    "Close \"{dialogTitle}\" dialog" : "Затвори дијалог „{dialogTitle}”",
    "Email length is at max (255)" : "Дужина и-мејла је максимална (255)",
    "Non-existing tag #{tag}" : "Непостојећа ознака #{tag}",
    "Restricted" : "Ограничена",
    "Invisible" : "Невидљива",
    "Delete" : "Обриши",
    "Rename" : "Преименуј",
    "Collaborative tags" : "Oзнаке сарадње",
    "No tags found" : "Ознаке нису нађене",
    "Clipboard not available, please copy manually" : "Клипборд није доступан, молимо вас да ручно копирате",
    "Personal" : "Лично",
    "Accounts" : "Налози",
    "Admin" : "Администрација",
    "Help" : "Помоћ",
    "Access forbidden" : "Забрањен приступ",
    "You are not allowed to access this page." : "Није вам дозвољено да приступите овој страници.",
    "Back to %s" : "Назад на %s",
    "Page not found" : "Страна није нађена",
    "The page could not be found on the server or you may not be allowed to view it." : "Страница не може да се пронађе на серверу или можда немате права да је видите.",
    "Too many requests" : "Превише захтева",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Са ваше мреже долази превише захтева. Покушајте поново касније или контактирајте администратора уколико је ово нека грешка.",
    "Error" : "Грешка",
    "Internal Server Error" : "Унутрашња грешка сервера",
    "The server was unable to complete your request." : "Сервер не може да обради Ваш захтев.",
    "If this happens again, please send the technical details below to the server administrator." : "Ако се ово понови, пошаљите техниче детаље испод администратору овог сервера.",
    "More details can be found in the server log." : "Више детаља се може наћи у дневнику сервера.",
    "For more details see the documentation ↗." : "За више детаља погледајте документацију ↗.",
    "Technical details" : "Технички детаљи",
    "Remote Address: %s" : "Удаљена адреса: %s",
    "Request ID: %s" : "ИД захтева: %s",
    "Type: %s" : "Тип: %s",
    "Code: %s" : "Кôд: %s",
    "Message: %s" : "Порука: %s",
    "File: %s" : "Фајл: %s",
    "Line: %s" : "Линија: %s",
    "Trace" : "Траг",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Делује као да покушавате да реинсталирате Nextcloud. Међутим, фајл CAN_INSTALL фали из конфигурационог директоријума, Молимо креирајте фајл CAN_INSTALL у овом директоријуму да бисте наставили.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Не могу да уклоним CAN_INSTALL из конфигурационе фасцикле. Уклоните овај фајл ручно.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Ова апликација захтева Јава скрипт за исправан рад. {linkstart}Омогућите Јава скрипт{linkend} и поново учитајте страницу.",
    "Skip to main content" : "Прескочи на главни садржај",
    "Skip to navigation of app" : "Прескочи на навигацију апликације",
    "Go to %s" : "Иди на %s",
    "Get your own free account" : "Узмите бесплатан налог",
    "Connect to your account" : "Повежите се на Ваш налог",
    "Please log in before granting %1$s access to your %2$s account." : "Прво се пријавите пре него што одобрите привилегију %1$s приступ Вашем налогу %2$s.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Ако не покушавате да подесите нови уређај или апликацију, неко покушава да Вас превари да му дате приступ Вашим подацима. У том случају, не настављајте и контактирајте администратора Вашег система.",
    "App password" : "Лозинка апликације",
    "Grant access" : "Одобри приступ",
    "Alternative log in using app password" : "Алтернативна пријава коришћењем лозинк апликације",
    "Account access" : "Приступ налогу",
    "Currently logged in as %1$s (%2$s)." : "Тренутно пријављен као %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Управо ћете одобрити %1$s приступ Вашем %2$s налогу.",
    "Account connected" : "Налог повезан",
    "Your client should now be connected!" : "Ваш клијент сада треба да је повезан!",
    "You can close this window." : "Можете затворити овај прозор.",
    "Previous" : "Претходно",
    "This share is password-protected" : "Ово дељење је заштићено лозинком",
    "The password is wrong or expired. Please try again or request a new one." : "Лозинка је погрешна или је истекла. Молимо вас да покушате поново, или затражите нову.",
    "Please type in your email address to request a temporary password" : "Молимо вас унесите своју и-мејл адресу да затражите привремену лозинку",
    "Email address" : "Адреса е-поште",
    "Password sent!" : "Лозинка је послата!",
    "You are not authorized to request a password for this share" : "Немате право да за овај дељени ресурс тражите лозинку",
    "Two-factor authentication" : "Двофакторска провера идентитета",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Повећана сигурност је омогућена за овај налог. Одаберите други фактор за проверу идентитета:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Није могуће учитати ниједан метод двофакторске провере идентитета. Контактирајте администратора.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Двофакторска провера идентитета је захтевана, али није још подешена на Вашем налогу. Контактирајте администратора за помоћ.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Двофакторска провера идентитета је захтевана, али није још подешена на Вашем налогу. Контактирајте администратора да подеси двофакторску проверу идентитета.",
    "Set up two-factor authentication" : "Подеси двофакторску проверу идентитета",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Двофакторска провера идентитета је захтевана, али није још подешена на Вашем налогу. Или употребите Ваше резервне кôдове, или контактирајте администратора за помоћ.",
    "Use backup code" : "Користите резервни кôд",
    "Cancel login" : "Откажи пријављивање",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Повећана сигурност је захтевана за овај налог. Одаберите провајдера којег желите да подесите:",
    "Error while validating your second factor" : "Грешка при провери Вашег другог фактора",
    "Access through untrusted domain" : "Приступ кроз небезбедни домен",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Контактирајте Вашег администратора. Ако сте Ви администратор, измените \"trusted_domains\" подешавање у config/config.php као у примеру config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Више информација о томе како ово подесити можете да нађете у %1$s документацији%2$s.",
    "App update required" : "Потребно ажурирање апликације",
    "%1$s will be updated to version %2$s" : "%1$s ће бити ажуриран на верзију %2$s",
    "The following apps will be updated:" : "Следеће апликације ће бити ажуриране:",
    "These incompatible apps will be disabled:" : "Ове неусаглашене апликације биће онемогућене:",
    "The theme %s has been disabled." : "Тема %s је онемогућена.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Проверите да ли сте направили резервну копију фасцикли са подешавањима и подацима пре него што наставите.",
    "Start update" : "Почни ажурирање",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Да избегнете прекорачење времена одзива на већим инсталацијама, можете покренути следећу команду у инсталационом директоријуму:",
    "Detailed logs" : "Детаљни дневници",
    "Update needed" : "Потребно је ажурирање",
    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Молимо вас да употребите ажурирање из конзоле пошто имате велику инстанцу са више од 50 налога.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "За помоћ, погледајте <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">документацију</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Свестан сам да уколико наставим ажурирање преко веб сучеља, постоји ризик да захтеву истекне време за извршење и да то може да изазове губитак података, али имам резервну копију и знам како да је повратим у случају грешке.",
    "Upgrade via web on my own risk" : "Надогради преко веба на сопствену одговорност",
    "Maintenance mode" : "Режим одржавања",
    "This %s instance is currently in maintenance mode, which may take a while." : "Овај %s је тренутно у режиму одржавања што може потрајати.",
    "This page will refresh itself when the instance is available again." : "Ова страница ће се сама освежити када инстанца постане поново доступна.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Контактирајте администратора ако се порука понавља или се неочекивано појавила.",
    "Error occurred while checking server setup" : "Дошло је до грешке при провери поставки сервера",
    "For more details see the {linkstart}documentation ↗{linkend}." : "За више детаља погледајте {linkstart}документацију ↗{linkend}.",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Ћаскање, видео позиви, дељење екрана, састанци на интернету & веб конференције – на десктоп рачунару и преко мобилних апликација.",
    "You have not added any info yet" : "Још увек нисте додали никакве информације",
    "{user} has not added any info yet" : "{user} још увек није унео никакве информације",
    "Error opening the user status modal, try hard refreshing the page" : "Грешка приликом отварања модалног прозора за статус корисника, покушајте да освежите страну уз брисање кеша",
    "Edit Profile" : "Уреди профил",
    "The headline and about sections will show up here" : "Овде ће се појавити насловна линија и одељак „о”",
    "Very weak password" : "Веома слаба лозинка",
    "Weak password" : "Слаба лозинка",
    "So-so password" : "Осредња лозинка",
    "Good password" : "Добра лозинка",
    "Strong password" : "Јака лозинка",
    "Profile not found" : "Није пронађен профил",
    "The profile does not exist." : "Профил не постоји.",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Ваш директоријум са подацима и фајлови су вероватно доступни са интернета јер .htaccess не ради.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "За информације како да правилно подесите Ваш сервер, погледајте <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">документацију</a>.",
    "<strong>Create an admin account</strong>" : " <strong>Направи административни налог</strong>",
    "New admin account name" : "Име новог административног налога",
    "New admin password" : "Лозинка новог административног налога",
    "Show password" : "Прикажи лозинку",
    "Toggle password visibility" : "Укључи/искључи видљивост лозинке",
    "Configure the database" : "Подешавање базе",
    "Only %s is available." : "Само %s је доступна.",
    "Database account" : "Налог базе података",
    "Direct link copied to clipboard" : "Директни линк је копиран у клипборд"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
